Connect WB cores command to UCI option Threads
authorH.G. Muller <h.g.muller@hccnet.nl>
Thu, 20 Dec 2012 14:00:57 +0000 (15:00 +0100)
committerH.G. Muller <h.g.muller@hccnet.nl>
Thu, 20 Dec 2012 14:00:57 +0000 (15:00 +0100)
UCI2WB.c

index 7256061..3035c94 100644 (file)
--- a/UCI2WB.c
+++ b/UCI2WB.c
@@ -33,7 +33,7 @@
 char move[2000][10], checkOptions[8192], iniPos[256], hashOpt[20], pause, pondering, suspended, ponder, post, hasHash, c, sc='c', *suffix, *variants;\r
 int mps, tc, inc, sTime, depth, myTime, hisTime, stm, computer = NONE, memory, oldMem=0, cores, moveNr, lastDepth, lastScore, startTime, debug;\r
 int statDepth, statScore, statNodes, statTime, currNr, size, collect, nr, sm, inex, on[500];\r
-char currMove[20], moveMap[500][10], /* for analyze mode */ canPonder[20];\r
+char currMove[20], moveMap[500][10], /* for analyze mode */ canPonder[20], threadOpt[20];\r
 \r
 FILE *toE, *fromE, *fromF;\r
 int pid;\r
@@ -238,6 +238,7 @@ Engine2GUI()
            if(p = strstr(line+6, " max "))  sscanf(p+1, "max %d", &max), *p = '\n';\r
            if(p = strstr(line+6, " default "))  sscanf(p+1, "default %[^\n]*", val), *p = '\n';\r
            if(p = strstr(line+6, " name ")) sscanf(p+1, "name %[^\n]*", name);\r
+           if(!strcmp(name, "Threads")) { strcpy(threadOpt, name); continue; }\r
            if(!strcmp(name, "Ponder") || !strcmp(name, "USI_Ponder")) { strcpy(canPonder, name); continue; }\r
            if(!strcmp(name, "Hash") || !strcmp(name, "USI_Hash")) {\r
                memory = oldMem = atoi(val); hasHash = 1; \r
@@ -420,7 +421,7 @@ GUI2Engine()
        else if(!strcmp(command, "hard") && !!*canPonder) ponder = 1, fprintf(toE, "setoption name %s value true\n", canPonder), StartPonder();\r
        else if(!strcmp(command, "ping"))   pause = 1, fprintf(toE, "isready\n"), fflush(toE), Sync(PAUSE), printf("pong %s", line+5);\r
        else if(!strcmp(command, "memory")) sscanf(line, "memory %d", &memory);\r
-       else if(!strcmp(command, "cores"))  sscanf(line, "cores %d", &cores);\r
+       else if(!strcmp(command, "cores")&& !!*threadOpt) sscanf(line, "cores %d", &cores), fprintf(toE, "setoption name %s value %d\n", threadOpt, cores);\r
        else if(!strcmp(command, "sd"))     sscanf(line, "sd %d", &depth);\r
        else if(!strcmp(command, "st"))     sscanf(line, "st %d", &sTime), sTime = 1000*sTime - 30, inc = 0;\r
        else if(!strcmp(command, "quit"))   fprintf(toE, "quit\n"), fflush(toE), exit(0);\r